@@ -15,18 +15,15 @@
 #   under the License.
 
 import json
-import os
-import sys
-
-from cliff.command import Command
-from cliff.lister import Lister
 
 from validations_libs import constants
 from validations_libs.validation_actions import ValidationActions
 from validations_libs.validation_logs import ValidationLogs
+from validations_libs.cli.base import BaseCommand
+from validations_libs.cli.base import BaseLister
 
 
-class ListHistory(Lister):
+class ListHistory(BaseLister):
     """Display Validations execution history"""
 
     def get_parser(self, parser):
@@ -36,6 +33,15 @@ class ListHistory(Lister):
                             metavar="<validation>",
                             type=str,
                             help='Display execution history for a validation')
+        parser.add_argument('--limit',
+                            dest='history_limit',
+                            type=int,
+                            default=15,
+                            help=(
+                                'Display <n> most recent '
+                                'runs of the selected <validation>. '
+                                '<n> must be > 0\n'
+                                'The default display limit is set to 15.\n'))
         parser.add_argument('--validation-log-dir', dest='validation_log_dir',
                             default=constants.VALIDATIONS_LOG_BASEDIR,
                             help=("Path where the validation log files "
@@ -43,11 +49,27 @@ class ListHistory(Lister):
         return parser
 
     def take_action(self, parsed_args):
+
+        if parsed_args.history_limit < 1:
+            raise ValueError(
+                (
+                    "Number <n> of the most recent runs must be > 0. "
+                    "You have provided {}").format(
+                        parsed_args.history_limit))
+        self.app.LOG.info(
+            (
+                "Limiting output to the maximum of "
+                "{} last validations.").format(
+                parsed_args.history_limit))
+
         actions = ValidationActions(parsed_args.validation_log_dir)
-        return actions.show_history(parsed_args.validation)
+
+        return actions.show_history(
+            validation_ids=parsed_args.validation,
+            history_limit=parsed_args.history_limit)
 
 
-class GetHistory(Command):
+class GetHistory(BaseCommand):
     """Display details about a Validation execution"""
 
     def get_parser(self, parser):
@@ -68,19 +90,40 @@ class GetHistory(Command):
         return parser
 
     def take_action(self, parsed_args):
+
+        self.app.LOG.debug(
+            (
+                "Obtaining information about the validation run {}\n"
+                "From directory {}"
+            ).format(
+                parsed_args.uuid,
+                parsed_args.validation_log_dir))
+
         vlogs = ValidationLogs(logs_path=parsed_args.validation_log_dir)
-        data = vlogs.get_logfile_content_by_uuid(parsed_args.uuid)
-        if data:
+
+        try:
+            log_files = vlogs.get_logfile_content_by_uuid(parsed_args.uuid)
+        except IOError as io_error:
+            raise RuntimeError(
+                (
+                    "Encountered a following IO error while attempting read a log "
+                    "file linked to UUID: {} .\n"
+                    "{}"
+                ).format(
+                    parsed_args.uuid,
+                    io_error))
+
+        if log_files:
             if parsed_args.full:
-                for d in data:
-                    print(json.dumps(d, indent=4, sort_keys=True))
+                for log_file in log_files:
+                    print(json.dumps(log_file, indent=4, sort_keys=True))
             else:
-                for d in data:
-                    for p in d.get('validation_output', []):
-                        print(json.dumps(p['task'],
+                for log_file in log_files:
+                    for validation_result in log_file.get('validation_output', []):
+                        print(json.dumps(validation_result['task'],
                                          indent=4,
                                          sort_keys=True))
         else:
             raise RuntimeError(
-                "Could not find the log file linked to this UUID: %s" %
-                parsed_args.uuid)
+                "Could not find the log file linked to this UUID: {}".format(
+                parsed_args.uuid))
