@@ -12,15 +12,18 @@
 #   License for the specific language governing permissions and limitations
 #   under the License.
 #
-DEFAULT_VALIDATIONS_BASEDIR = '/usr/share/ansible/'
+import os
+
+DEFAULT_VALIDATIONS_BASEDIR = '/usr/share/ansible'
 
 ANSIBLE_VALIDATION_DIR = '/usr/share/ansible/validation-playbooks'
 
-VALIDATION_GROUPS_INFO = '%s/groups.yaml' % DEFAULT_VALIDATIONS_BASEDIR
+VALIDATION_GROUPS_INFO = os.path.join(
+    DEFAULT_VALIDATIONS_BASEDIR,
+    'groups.yaml')
 
-VALIDATION_GROUPS = ['no-op',
-                     'prep',
-                     'post']
+VALIDATIONS_LOG_BASEDIR = os.path.join(os.environ.get('HOME'), 'validations')
 
-VALIDATIONS_LOG_BASEDIR = '/var/log/validations/'
-VALIDATION_ANSIBLE_ARTIFACT_PATH = '/var/log/validations/artifacts/'
+VALIDATION_ANSIBLE_ARTIFACT_PATH = os.path.join(
+    VALIDATIONS_LOG_BASEDIR,
+    'artifacts')
