@@ -46,10 +46,17 @@ class ValidationActions(object):
                                 else constants.ANSIBLE_VALIDATION_DIR)
 
     def list_validations(self, group=None):
-        """Get a list of the available validations
-
+        """Get a list of the validations selected by group
+        membership. With their names and group membership information.
         This is used to print table from python ``Tuple`` with ``PrettyTable``.
 
+        :param group: Group or multiple groups of validations.
+                      Additional groups have to be separated by comma.
+        :type group: `string`
+
+        :return: Column names and a list of the selected validations
+        :rtype: `tuple`
+
         .. code:: text
 
             ----------------+--------------------------+----------------------+
@@ -60,9 +67,6 @@ class ValidationActions(object):
             | validation3   | Name of the validation3  | ['group4]            |
             +---------------+--------------------------+----------------------+
 
-        :return: The list of the available validations
-        :rtype: `tuple`
-
         :Example:
 
         >>> path = "/foo/bar"
@@ -74,16 +78,21 @@ class ValidationActions(object):
           ('validation2', 'Name of the validation2', ['group1', 'group2'])])
         """
         self.log = logging.getLogger(__name__ + ".list_validations")
+
         validations = v_utils.parse_all_validations_on_disk(
             self.validation_path, group)
 
-        return_values = []
-        column_name = ('ID', 'Name', 'Groups')
+        self.log.debug(
+            "Parsed {} validations.".format(len(validations))
+        )
 
-        for val in validations:
-            return_values.append((val.get('id'), val.get('name'),
-                                  val.get('groups')))
-        return (column_name, return_values)
+        return_values = [
+            (val.get('id'), val.get('name'), val.get('groups'))
+            for val in validations]
+
+        column_names = ('ID', 'Name', 'Groups')
+
+        return (column_names, return_values)
 
     def show_validations(self, validation,
                          log_path=constants.VALIDATIONS_LOG_BASEDIR):
@@ -203,12 +212,29 @@ class ValidationActions(object):
                     return None, _hosts
         return playbook, limit_hosts
 
+    def _retrieve_latest_results(self, logs, history_limit):
+        """Retrieve the most recent validation results.
+        Previously retrieved logs are sorted in ascending order,
+        with the last time the file was modified serving as a key.
+        Finally we take the last `n` logs, where `n` == `history_limit`
+        and return them while discarding the time information.
+        """
+
+        history_limit = min(history_limit, len(logs))
+
+        logs = sorted(
+                [(os.stat(path).st_mtime, path) for path in logs],
+                key=lambda path: path[0])
+
+        return [path[1] for path in logs[-history_limit:]]
+
     def run_validations(self, validation_name=None, inventory='localhost',
                         group=None, extra_vars=None, validations_dir=None,
                         extra_env_vars=None, ansible_cfg=None, quiet=True,
                         workdir=None, limit_hosts=None, run_async=False,
                         base_dir=constants.DEFAULT_VALIDATIONS_BASEDIR,
-                        log_path=None, python_interpreter=None,
+                        log_path=constants.VALIDATIONS_LOG_BASEDIR,
+                        python_interpreter=None,
                         skip_list=None,
                         callback_whitelist=None,
                         output_callback='validation_stdout',
@@ -248,6 +274,8 @@ class ValidationActions(object):
                          ``constants.DEFAULT_VALIDATIONS_BASEDIR``)
         :type base_dir: ``string``
         :param log_path: The absolute path of the validations logs directory
+                         (Defaults to
+                         ``constants.VALIDATIONS_LOG_BASEDIR``)
         :type log_path: ``string``
         :param python_interpreter: Path to the Python interpreter to be
                                    used for module execution on remote targets,
@@ -333,6 +361,7 @@ class ValidationActions(object):
         else:
             raise RuntimeError("No validations found")
 
+        log_path = v_utils.create_log_dir(log_path)
         self.log.debug('Running the validations with Ansible')
         results = []
         for playbook in playbooks:
@@ -343,7 +372,7 @@ class ValidationActions(object):
                                                 limit_hosts)
             if _play:
                 validation_uuid, artifacts_dir = v_utils.create_artifacts_dir(
-                    dir_path=log_path, prefix=os.path.basename(playbook))
+                    log_path=log_path, prefix=os.path.basename(playbook))
                 run_ansible = v_ansible(validation_uuid)
                 _playbook, _rc, _status = run_ansible.run(
                     workdir=artifacts_dir,
@@ -378,7 +407,7 @@ class ValidationActions(object):
             return results
         # Return log results
         uuid = [id['UUID'] for id in results]
-        vlog = ValidationLogs()
+        vlog = ValidationLogs(log_path)
         return vlog.get_results(uuid)
 
     def group_information(self, groups):
@@ -484,23 +513,41 @@ class ValidationActions(object):
                                                     group)
         if download_file:
             params_only = {}
-            with open(download_file, 'w') as f:
-                for val_name in params.keys():
-                    params_only.update(params[val_name].get('parameters'))
+            try:
+                with open(download_file, 'w') as parameters_file:
+                    for val_name in params.keys():
+                        params_only.update(params[val_name].get('parameters'))
 
-                if output_format == 'json':
-                    f.write(json.dumps(params_only,
+                    if output_format == 'json':
+                        parameters_file.write(
+                            json.dumps(params_only,
                                        indent=4,
                                        sort_keys=True))
-                else:
-                    f.write(yaml.safe_dump(params_only,
+                    else:
+                        parameters_file.write(
+                            yaml.safe_dump(params_only,
                                            allow_unicode=True,
                                            default_flow_style=False,
                                            indent=2))
+                self.log.debug(
+                    "Validations parameters file {} saved as {} ".format(
+                        download_file,
+                        output_format))
+
+            except (PermissionError, OSError) as error:
+                self.log.exception(
+                    (
+                        "Exception {} encountered while tring to write "
+                        "a validations parameters file {}"
+                    ).format(
+                        error,
+                        download_file))
+
         return params
 
     def show_history(self, validation_ids=None, extension='json',
-                     log_path=constants.VALIDATIONS_LOG_BASEDIR):
+                     log_path=constants.VALIDATIONS_LOG_BASEDIR,
+                     history_limit=None):
         """Return validation executions history
 
         :param validation_ids: The validation ids
@@ -509,6 +556,9 @@ class ValidationActions(object):
         :type extension: ``string``
         :param log_path: The absolute path of the validations logs directory
         :type log_path: ``string``
+        :param history_limit: The number of most recent history logs
+                              to be displayed.
+        :type history_limit: ``int``
 
         :return: Returns the information about the validation executions
                  history
@@ -559,10 +609,15 @@ class ValidationActions(object):
                 validation_ids = [validation_ids]
             logs = []
             for validation_id in validation_ids:
-                logs.extend(vlogs.get_logfile_by_validation(validation_id))
+                logs.extend(
+                    vlogs.get_logfile_by_validation(
+                        validation_id))
         else:
             logs = vlogs.get_all_logfiles(extension)
 
+        if history_limit and history_limit < len(logs):
+            logs = self._retrieve_latest_results(logs, history_limit)
+
         values = []
         column_name = ('UUID', 'Validations',
                        'Status', 'Execution at',
